Module: RSpec
- Defined in:
- lib/rspec/parallel.rb,
lib/rspec/parallel/runner.rb,
lib/rspec/parallel/version.rb,
lib/rspec/parallel/command_line.rb,
lib/rspec/parallel/configuration.rb,
lib/rspec/parallel/option_parser.rb,
lib/rspec/parallel/configuration_options.rb,
lib/rspec/parallel/example_thread_runner.rb,
lib/rspec/parallel/example_group_thread_runner.rb
Defined Under Namespace
Modules: Parallel
Class Method Summary collapse
-
.configuration ⇒ Object
Returns the global [Configuration](RSpec/Parallel/Configuration) object.
Class Method Details
.configuration ⇒ Object
Returns the global [Configuration](RSpec/Parallel/Configuration) object. While you can use this method to access the configuration, the more common convention is to use [RSpec.configure](RSpec#configure-class_method).
29 30 31 32 33 34 35 36 |
# File 'lib/rspec/parallel.rb', line 29 def self.configuration @configuration ||= begin config = RSpec::Parallel::Configuration.new config.expose_dsl_globally = true config end end |